use serde::{Serialize, Deserialize};
use chrono::{DateTime, Utc};
use crate::client::RecordType;

#[derive(Debug, Deserialize)]
pub struct TxtVerification {
    pub name: String,
    pub token: String
}

#[derive(Debug, Deserialize)]
pub struct Pagination {
    pub page: u32,
    pub per_page: u32,
    pub last_page: u32,
    pub total_entries: u32
}

#[derive(Debug, Deserialize)]
pub struct Meta {
    pub pagination: Pagination
}

#[derive(Debug, Deserialize)]
pub struct Zone {
    pub id: String,
    pub created: DateTime<Utc>,
    pub modified: DateTime<Utc>,
    pub legacy_dns_host: String,
    pub legacy_dns: Vec<String>,
    pub ns: Vec<String>,
    pub owner: String,
    pub paused: bool,
    pub permission: String,
    pub project: String,
    pub registrar: String,
    pub status: String,
    pub ttl: u32,
    pub verified: DateTime<Utc>,
    pub records_count: u32,
    pub is_secondary_dns: bool,
    pub txt_verification: Vec<TxtVerification>
}

#[derive(Debug, Deserialize)]
pub struct ZoneResult {
    pub zones: Vec<Zone>,
    pub meta: Meta
}

#[derive(Debug, Serialize, Deserialize)]
pub struct RecordPayload {
    zone_id: String,
    r#type: RecordType,
    name: String,
    value: String,
    ttl: u64
}

#[derive(Debug, Serialize, Deserialize)]
pub struct Record {
    id: String,
    created: DateTime<Utc>,
    modified: DateTime<Utc>,
    zone_id: String,
    r#type: String,
    name: String,
    value: String,
    ttl: u64
}

#[derive(Debug, Serialize, Deserialize)]
pub struct RecordResult {
    pub record: Record
}

#[derive(Debug, Serialize, Deserialize)]
pub struct RecordsResult {
    pub records: Vec<Record>
}
